#!/bin/bash
#
# Remaster a Live_CD (myPuppy.iso) based on HD Installation
# 07/15/2005 - DrJ
# 

export RAMDISKSIZE=20480
export STAGE="/mnt/data/stage"
export MOUNTPT="/mnt/image"

# basic preparation
clear
echo -e "\\033[1;34m"                                                           
echo -e "\tRemastering a live-CD based on HD installation ..."                                                                 
echo -en "\\033[0;39m"

mkdir -p $STAGE
rm -f $STAGE/*

cat > $STAGE/isolinux.cfg <<EOF1
default 1
display boot.msg
prompt 1
timeout 600

label 1
  kernel vmlinuz
  append root=/dev/ram0 initrd=image.gz ramdisk_size=$RAMDISKSIZE PFILE=pup001-none-262144
label 2
  kernel vmlinuz
  append root=/dev/ram0 initrd=image.gz ramdisk_size=$RAMDISKSIZE PFILE=no
label 3
  kernel vmlinuz
  append root=/dev/ram0 initrd=image.gz acpi=off ramdisk_size=$RAMDISKSIZE PFILE=pup001-none-262144
label 4
  kernel vmlinuz
  append root=/dev/ram0 initrd=image.gz acpi=off ramdisk_size=$RAMDISKSIZE PFILE=no
label 5
  kernel vmlinuz
  append root=/dev/ram0 initrd=image.gz ramdisk_size=$RAMDISKSIZE PFILE=cd
EOF1

##echo -e "\030goofy.16\015" > $STAGE/boot.msg

cat > $STAGE/boot.msg <<EOF2

    1 - Save Personal Data on Hard Drive
    2 - Don't Save Data
    3 - Save Personal Data on Hard Drive, and acpi=off
    4 - Don't Save Data, and acpi=off
    5 - Save Personal Data on Multi-Session CD

EOF2


# some static files
cp -a goofy.16 $STAGE
cp -a /boot/vmlinuz /usr/sbin/isolinux.bin $STAGE

# prepare initrd image
echo -e "\\033[1;34m"  
echo -e "\tPreparing for initrd ..."
echo -en "\\033[0;39m"
dd if=/dev/zero of=$STAGE/image bs=1k count=$RAMDISKSIZE 1> /dev/null
losetup -d /dev/loop2 >/dev/null 2>&1
losetup-FULL /dev/loop2 $STAGE/image
mkdir -p $MOUNTPT
mke2fs -F $STAGE/image >/dev/null
mount -t ext2 /dev/loop2 $MOUNTPT
cd /
cp -a bin dev lib sbin var $MOUNTPT
cp -a root $MOUNTPT/root0
cat /dev/null > $MOUNTPT/var/log/messages
cat /dev/null > $MOUNTPT/var/log/wtmp
cp -a $MOUNTPT/var $MOUNTPT/var0
sync
mkdir -p $MOUNTPT/{proc,tmp,root}
mkdir -p $MOUNTPT/mnt/{cdrom,data,floppy,hda1,sda1,loop} 
cd $MOUNTPT 
ln -sf root0/.etc etc
mkdir -p $MOUNTPT/proc/sys/net/ipv4
mkdir -p $MOUNTPT/proc/self/fd
cd $MOUNTPT/proc/self/fd
ln -s /dev/pts/0 0
ln -s /dev/pts/0 1
ln -s /dev/pts/0 2
ln -s /dev/pts/0 255
cp -a $MOUNTPT/proc $MOUNTPT/proc0

# customize /etc and others
rm -f $MOUNTPT/dev/cdrom
mv -f $MOUNTPT/sbin/init_ORIG $MOUNTPT/sbin/init
cd $MOUNTPT/etc
echo -n $RAMDISKSIZE > $MOUNTPT/etc/ramdisksize
echo -n $RAMDISKSIZE > $MOUNTPT/etc/ramdiskfssize
echo "62914560" > $MOUNTPT/etc/sizeusrcram
rm -f ramdiskphysicalfssize
rm -f mtab key* *map mouse* videomode codepage scsiemul
echo "/dev/ram0     /            ext2     defaults               0 0" > $MOUNTPT/etc/fstab
echo "none          /proc        proc     defaults               0 0" >> $MOUNTPT/etc/fstab
echo "none          /dev/pts     devpts   gid=2,mode=620         0 0" >> $MOUNTPT/etc/fstab
echo "/dev/fd0      /mnt/floppy  auto     noauto,user,rw         0 0" >> $MOUNTPT/etc/fstab
echo "/dev/cdrom    /mnt/cdrom   iso9660  noauto,user,ro         0 0" >> $MOUNTPT/etc/fstab
echo "/dev/loop0    /usr         cramfs   defaults               0 0" >> $MOUNTPT/etc/fstab
sync

# make image.gz
echo -e "\\033[1;34m"  
echo -e "\tMaking image.gz ..."
echo -en "\\033[0;39m"
dd if=/dev/loop2 bs=1k count=$RAMDISKSIZE | gzip - > $STAGE/image.gz
sync
cd /
umount $MOUNTPT
rm -f $STAGE/image

# make usr_cram.fs file, using squashfs
echo -e "\\033[1;34m"  
echo -e "\tMaking usr_cram.fs ..."
echo -en "\\033[0;39m"
mksquashfs /usr $STAGE/usr_cram.fs 1> /dev/null
sync

cd $STAGE
rm -f myPuppy.iso boot.cat
echo -e "\\033[1;34m"  
echo -e "\tMaking bootable ISO file ..."
echo -en "\\033[0;39m"
mkisofs -o $STAGE/myPuppy.iso -b isolinux.bin -c boot.cat -no-emul-boot -boot-load-size 4 -boot-info-table $STAGE 1>/dev/null
sync

# Clean-up
find $STAGE -type f ! -name myPuppy.iso -exec rm {} \;

echo -e "\\033[1;34m"  
echo -e "\n\tAll Done!\n \tYour myPuppy.iso is in $STAGE\n"
echo -en "\\033[0;39m"

